// Copyright (c) 2009, Richard Switzer <rswitzer@medlir.com>
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without modification, 
// are permitted provided that the following conditions are met:
//
// - Redistributions of source code must retain the above copyright notice, this 
//   list of conditions and the following disclaimer.
// - Redistributions in binary form must reproduce the above copyright notice, this 
//   list of conditions and the following disclaimer in the documentation and/or 
//   other materials provided with the distribution.
// - Neither the name of the author nor the names of its contributors may be used 
//   to endorse or promote products derived from this software without specific 
//   prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
// IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
// INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT 
// NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR 
// PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
// WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
// POSSIBILITY OF SUCH DAMAGE.

using System;
using System.Windows.Forms;
using System.IO;
using gma.System.Windows;

namespace CPlayer
{
  static class Program
  {
    static UserActivityHook actHook;
    
    [STAThread]
    static void Main()
    {
      NotifyIcon trayIcon = new NotifyIcon();
      trayIcon.Click += new EventHandler(trayIcon_Click);
      trayIcon.Visible = true;
      trayIcon.Icon = CPlayer.Properties.Resources.BillyMays;
      CPlay cp = new CPlay();
      actHook.Start();
      Application.Run();
      actHook.Stop();
    }

    static void trayIcon_Click(object sender, EventArgs e)
    {
      Application.Exit();
    }

    public class CPlay
    {
      private bool isShiftDown = false;

      public CPlay()
      {
        actHook = new UserActivityHook(); // crate an instance with global hooks
        actHook.KeyDown += new KeyEventHandler(MyKeyDown);
        actHook.KeyUp += new KeyEventHandler(MyKeyUp);
      }

      private void MyKeyDown(object sender, KeyEventArgs e)
      {
        if (e.KeyCode == Keys.LShiftKey || e.KeyCode == Keys.RShiftKey)
        {
          isShiftDown = true;
        }
        if (e.KeyCode == Keys.Capital)
        {
          if (isShiftDown == false)
          {
            e.Handled = true; 
            System.Diagnostics.Trace.WriteLine("Caps DOWN, Shift OFF... do Billy...");
          }
        }
      }

      private void MyKeyUp(object sender, KeyEventArgs e)
      {
        if (e.KeyCode == Keys.LShiftKey || e.KeyCode == Keys.RShiftKey)
        {
          isShiftDown = false;
        }
        if (e.KeyCode == Keys.Capital)
        {
          if (isShiftDown == false)
          {
            e.Handled = true;
            System.Diagnostics.Trace.WriteLine("Caps UP, Shift OFF... play wave...");
            string[] resultFileNames = Directory.GetFiles(@".", "*.wav");
            if (resultFileNames.Length > 0)
            {
              Random random = new Random();
              int num = random.Next(resultFileNames.Length);
              System.Diagnostics.Trace.WriteLine("Files: " + resultFileNames.Length.ToString());
              System.Diagnostics.Trace.WriteLine("Picked: " + num.ToString());
              System.Media.SoundPlayer myPlayer = new System.Media.SoundPlayer();
              myPlayer.SoundLocation = resultFileNames[num];
              myPlayer.Play();
            }
            else
            {
              MessageBox.Show("Please place at least one .wav file in the application directory.");
            }
          }
        }
      }
    }
  } // End of Program Class.
}